==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/pt_BR.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tarefas",
    "Due yesterday" : "Programada para ontem",
    "Due today" : "Programada para hoje",
    "Due tomorrow" : "Programada para amanhã",
    "Due on" : "Programada em",
    "Started yesterday" : "Iniciada ontem",
    "Starts today" : "Inicia hoje",
    "Starts tomorrow" : "Inicia amanhã",
    "Started on" : "Iniciada em",
    "Starts on" : "Inicia em",
    "[Remind me yesterday at ]HH:mm" : "[Lembrar-me ontem as ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Lembre-me hoje as ] HH: mm",
    "[Remind me tomorrow at ]HH:mm" : "[Lembre-me amanhã as ] HH: mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Lembre-me em] MMM DD, AAAA, [ as ] HH: mm",
    "Yesterday" : "Ontem",
    "Today" : "Hoje",
    "Tomorrow" : "Amanhã",
    "in %s" : "em %s",
    "%s ago" : "%s atrás",
    "seconds" : "segundos",
    "a minute" : "um minuto",
    "%d minutes" : "%d minutos",
    "an hour" : "uma hora",
    "%d hours" : "%d horas",
    "a day" : "um dia",
    "%d days" : "%d dias",
    "a month" : "um mês",
    "%d months" : "%d meses",
    "a year" : "um ano",
    "%d years" : "%d anos",
    "week" : "semana",
    "weeks" : "semanas",
    "day" : "dia",
    "days" : "dias",
    "hour" : "hora",
    "hours" : "horas",
    "minute" : "minuto",
    "minutes" : "minutos",
    "second" : "segundo",
    "before beginning" : "antes de começar",
    "after beginning" : "depois de começar",
    "before end" : "antes do final",
    "after end" : "depois do final",
    "Comment" : "Comentário",
    "Add a comment" : "Adicionar um comentário",
    "This will delete the Calendar \"%s\" and all of its entries." : "Isto irá apagar o Calendário \"%s\" e todas as suas entradas.",
    "The name \"%s\" is already used." : "O nome \"%s\" já está sendo usado.",
    "An empty name is not allowed." : "Um nome vazio não é permitido.",
    "Hidden" : "Oculto",
    "Visible" : "Visível",
    "Automatic" : "Automático",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Add an important item in \"%s\"..." : "Adicionar um importante item em \"%s\"...",
    "Add an item due today in \"%s\"..." : "Adicionar um item programado para hoje em \"%s\"...",
    "Add an item in \"%s\"..." : "Adicionar um item a \"%s\"...",
    "Add a current item in \"%s\"..." : "Adicionar um item corrente a \"%s\"...",
    "Add a subtask to \"%s\"..." : "Adicionar uma sub-tarefa para \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas"],
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "Set due date" : "Definir data de vencimento",
    "%s %% completed" : "%s %% concluída",
    "priority %s: " : "prioridade %s:",
    "high" : "alta",
    "medium" : "média",
    "low" : "baixa",
    "no priority assigned" : "nenhuma prioridade atribuída",
    "Remind me" : "Lembre-me",
    "at the end" : "no final",
    "at the beginning" : "no início",
    "Set start date" : "Definir data de início",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Unnamed" : "Sem nome",
    "Important" : "Importante",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Corrente",
    "Completed" : "Concluído",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "Edit" : "Editar",
    "Link" : "Link",
    "Download" : "Baixar",
    "Save" : "Salvar",
    "Add List..." : "Adicionar a Lista...",
    "New List" : "Nova Lista",
    "Settings" : "Configurações",
    "Start of week" : "Começo da semana",
    "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
    "Change sort order" : "Modificar ordem de classificação",
    "Default" : "Padrão",
    "Due date" : "Data de Vencimento",
    "Start date" : "Data de início",
    "Priority" : "Prioridade",
    "Alphabetically" : "Alfabeticamente",
    "Manually" : "Manualmente",
    "Load remaining completed tasks." : "Carregando o restante das tarefas concluídas.",
    "All day" : "Todo dia",
    "(New category)" : "(Nova categoria)",
    "Select categories..." : "Selecione categorias...",
    "Loading the task..." : "Carregando a tarefa...",
    "Task not found!" : "Tarefa não encontrada!",
    "add a subtask to" : "adicionar uma sub-terefa para"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/pt_BR.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tarefas",
    "Due yesterday" : "Programada para ontem",
    "Due today" : "Programada para hoje",
    "Due tomorrow" : "Programada para amanhã",
    "Due on" : "Programada em",
    "Started yesterday" : "Iniciada ontem",
    "Starts today" : "Inicia hoje",
    "Starts tomorrow" : "Inicia amanhã",
    "Started on" : "Iniciada em",
    "Starts on" : "Inicia em",
    "[Remind me yesterday at ]HH:mm" : "[Lembre-me ontem às ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Lembre-me hoje às ] HH: mm",
    "[Remind me tomorrow at ]HH:mm" : "[Lembre-me amanhã às ] HH: mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Lembre-me em] MMM DD, YYYY, [ às ] HH: mm",
    "Yesterday" : "Ontem",
    "Today" : "Hoje",
    "Tomorrow" : "Amanhã",
    "in %s" : "em %s",
    "%s ago" : "%s atrás",
    "seconds" : "segundos",
    "a minute" : "um minuto",
    "%d minutes" : "%d minutos",
    "an hour" : "uma hora",
    "%d hours" : "%d horas",
    "a day" : "um dia",
    "%d days" : "%d dias",
    "a month" : "um mês",
    "%d months" : "%d meses",
    "a year" : "um ano",
    "%d years" : "%d anos",
    "week" : "semana",
    "weeks" : "semanas",
    "day" : "dia",
    "days" : "Dias",
    "hour" : "hora",
    "hours" : "horas",
    "minute" : "minuto",
    "minutes" : "minutos",
    "second" : "segundo",
    "before beginning" : "antes de começar",
    "after beginning" : "depois de começar",
    "before end" : "antes do final",
    "after end" : "depois do final",
    "Comment" : "Comente",
    "Add a comment" : "Adicionar um comentário",
    "This will delete the Calendar \"%s\" and all of its entries." : "Isto vai borrar o Calendário \"%s\" e todas as suas entradas.",
    "The name \"%s\" is already used." : "O nome \"%s\" já está em uso.",
    "An empty name is not allowed." : "Não é permitido nome em branco",
    "Hidden" : "Oculto",
    "Visible" : "Visível",
    "Automatic" : "Automático",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Add an important item in \"%s\"..." : "Adicionar um item importante em \"%s\"...",
    "Add an item due today in \"%s\"..." : "Adicionar um item programado para hoje em \"%s\"...",
    "Add an item in \"%s\"..." : "Adicionar um item a \"%s\"...",
    "Add a current item in \"%s\"..." : "Adicionar um item corrente a \"%s\"...",
    "Add a subtask to \"%s\"..." : "Adicionar uma sub-tarefa para \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas"],
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "Set due date" : "Definir data programada",
    "%s %% completed" : "%s %% concluída",
    "priority %s: " : "prioridade %s:",
    "high" : "alta",
    "medium" : "média",
    "low" : "baixa",
    "no priority assigned" : "nenhuma prioridade atribuída",
    "Remind me" : "Lembre-me",
    "at the end" : "no final",
    "at the beginning" : "no início",
    "Set start date" : "Definir data de início",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Unnamed" : "Sem nome",
    "Important" : "Importante",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Corrente",
    "Completed" : "Concluído",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "Edit" : "Editar",
    "Link" : "Link",
    "Download" : "Baixar",
    "Save" : "Salvar",
    "Add List..." : "Adicionar Lista...",
    "New List" : "Nova Lista",
    "Settings" : "Configurações",
    "Start of week" : "Começo da semana",
    "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
    "Change sort order" : "Alterar a ordem de classificação",
    "Default" : "Padrão",
    "Due date" : "Data programada",
    "Start date" : "Data de início",
    "Priority" : "Prioridade",
    "Alphabetically" : "Alfabeticamente",
    "Manually" : "Manualmente",
    "Load remaining completed tasks." : "Carregando o restante das tarefas concluídas.",
    "Task is completed" : "Tarefa concluída",
    "All day" : "Todo dia",
    "(New category)" : "(Nova categoria)",
    "Select categories..." : "Selecione categorias...",
    "Loading the task..." : "Carregando a tarefa...",
    "Task not found!" : "Tarefa não encontrada!",
    "add a subtask to" : "adicionar uma sub-tarefa para",
    "Toggle subtasks" : "Alternar subtarefas",
    "Toggle completed subtasks" : "Alternar subtarefas concluídas"
},
"nplurals=2; plural=(n > 1);");
